@@ -1,5 +1,5 @@
 from .scalar_resolver import ScalarResolver
 
 class EvalResolver(ScalarResolver):
-    def resolve(self, value, *_, **__):
+    def resolve(self, value, **__):
         return eval(value)
\ No newline at end of file
